
/*

Some of these compilers don't like // comments. So don't use them!

Hey! See INCLUDE/EXCLUDE macros!

*/

#define IDENTIFICATION1 "2004-01-27 FORTUNE 2.07, William W. Patterson"
#define IDENTIFICATION2 "mailto:webmaster@komputado.com"
#define IDENTIFICATION3 "http://www.komputado.com/iloj/diversaj.htm"

/*****************************************************************************

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

Usage:

   Cookies must be less than 81 characters long.

   fortune                    to use the internal array of fortune cookies
   fortune filename           to use your own file of fortune cookies
   fortune ?                  to identify program

Notes:

   The Classic Fortune Algorithm...

   Traditionally, this is how a cookie is selected: First, cookie
   #1 is named The Cookie. Then, using a random number generator,
   cookie #2 is given a 1/2 chance of replacing The Cookie. And so
   on, with cookie #n having a 1/n chance of becoming The Cookie.
   If you do the math, you find that all cookies have an equal
   chance to be The Cookie!

   To give a cookie a greater probability, duplicate it.

   After all cookies have been read, The Cookie is printed.

   This program has been compiled with...
      MSDOS & Micro C
         cc fortune.c -fop
      MSDOS & Pacific C
         pacc fortune.c
      MSDOS & MSC 6.0
         cl fortune.c
      UNIX System V/386 Release 3.2 & its standard compiler
         cc -ofortune fortune.c
      HPUX 10.20 & its standard compiler
         cc -ofortune fortune.c
      GNU/Linux & its standard compiler
         gcc -ofortune fortune.c

   Micro C handles function pointers in a nonstandard fashion.
   I also had to tweak the program a bit for the random numbers.

   Micro C can handle fewer cookies than the others. That's why I
   have ifdefed some cookies out if _MICROC_ is not defined. But I
   haven't kept up with that limitation, so if you ever recompile
   with Micro C, you may have to remove some more, or you may have
   room to add more.

Authors:

   William W. Patterson

History:

   1998-05-15  1.00  WWP   Creation, under HPUX 10.20.
   1998-05-20  1.10  WWP   Modified for Micro C & System V.
   1998-06-07  1.11  WWP   Added a couple new cookies, removed some old.
   1998-07-11  1.12  WWP   Added a couple new cookies, removed some old.
   1998-07-29  1.20  WWP   Added a couple include files that Pacific C wants, HPUX doesn't care about, and Micro C lacks.
   1998-07-29  1.21  WWP   Micro C limits the size of the internal fortunes array much more than the others do. Add new fortunes inside the ifndef block.
   1998-07-30  1.22  WWP   Added some cookies.
   1998-07-31  1.23  WWP   Another cookie.
   1998-08-02  1.24  WWP   Some more Occidental cookies.
   1998-08-15  1.25  WWP   More cookies.
   1998-08-16  1.26  WWP   The Zippy2000 quote: An Original!
   1998-08-23  1.27  WWP   Original: Highlighted Words...
   1998-08-29  1.28  WWP   Added some cookies.
   1998-09-04  1.29  WWP   Added some cookies.
   1998-09-06  1.30  WWP   Added some cookies.
   1998-09-21  1.31  WWP   Added some cookies.
   1998-09-25  1.32  WWP   Fixed a typo.
   1998-10-04  1.33  WWP   More cookies! More! More! More!
   1998-10-17  1.34  WWP   More cookies.
   1998-10-24  1.35  WWP   More cookies.
   1998-11-08  1.40  WWP   Use hoismo, not -x- (which is nonambiguous, but ugly).
   1998-11-27  1.41  WWP   It's TEOTWAWKI...
   1998-11-27  1.42  WWP   Commented some cookies and changed some weights.
   1998-11-29  1.43  WWP   Added some cookies.
   1998-12-26  1.44  WWP   Added some cookies.
   1998-12-27  1.45  WWP   Added cookies, commented some, changed some weights.
   1999-01-01  1.46  WWP   Added some cookies.
   1999-01-25  1.47  WWP   Added some cookies.
   1999-02-14  1.48  WWP   Added Latin cookies.
   1999-05-04  1.49  WWP   Added German proverbs, sayings, tongue twisters, and a really long word.
   1999-07-11  1.50  WWP   Added an original, pruned some oldies.
   1999-09-13  1.51  WWP   Added one, commented a bunch.
   1999-10-13  1.60  WWP   Cleaned up for release.
   2000-04-28  1.70  WWP   Commented some old fortunes, added some new ones.
   2000-04-28  1.71  WWP   Invalid file argument prompts (improved) help.
   2000-04-28  1.72  WWP   Love, Peace and Shonen Knife!
   2000-09-22  1.73  WWP   System V/386 doesn't like // comments.
   2000-09-22  1.74  WWP   Added some cookies.
   2000-09-22  2.00  WWP   Implemented INCLUDE/EXCLUDE macros.
   2000-09-25  2.01  WWP   Enhanced for GNU/Linux. Substituted the name "cookie" for "inline", because "inline" has a special meaning for gcc.
   2001-01-13  2.02  WWP   Added some cookies.
   2001-03-12  2.03  WWP   Added some, excluded some.
   2001-05-30  2.04  WWP   Added some.
   2001-12-12  2.05  WWP   Added some, and updated the identifications.
   2002-08-22  2.06  WWP   Added some, and updated the identifications.
   2004-01-27  2.07  WWP   Corrected the Tuesday quote (House at Pooh Corner).
   2004-01-27  2.07  WWP   Added Rod Stewart raincoat quote.

*****************************************************************************/

#include <stdio.h>

#ifndef _MICROC_
#include <stdlib.h>
#include <time.h>
#include <string.h>
#endif

#define MAXLENGTH 81

#define EXCLUDE(x)
#define INCLUDE(x) x,

static char *fortunes[] = {
   /* Classics... */
   INCLUDE("xyzzy!")
   INCLUDE("plugh!")
   /* Originals... my cookie classics, that is, not necessarily *mine*, though some are... */
   EXCLUDE("Why do bars have parking lots?")
   INCLUDE("I before E except where it's not.") /* wwp */
   INCLUDE("a lowtech guy in a hightech world") /* wwp */
   INCLUDE("The brutality of clocks. Listen for the alarm. Wake up!") /* wwp */
   INCLUDE("Those who don't forget the past are doomed to relive it.") /* wwp */
   INCLUDE("It's not Rocket Science. But then, nothing is.") /* wwp */
   INCLUDE("I do live within my means. But my ex does too!") /* wwp */
   INCLUDE("But perhaps the highlighted words are the ones you don't have to read again.") /* wwp */
   EXCLUDE("Zippy2000: Am I compliant yet?") /* wwp */
   INCLUDE("One man's poison is another man's Gift.") /* wwp */
   INCLUDE("One man's fish is another man's poisson.")
   INCLUDE("There's nothing a capitalist hates more than a free market.") /* wwp */
   INCLUDE("Real Programmers don't use floating point.")
   INCLUDE("The glass is neither half-empty nor half-full. The glass is too big.")
   INCLUDE("Even more than vacuum, Nature abhors discontinuities.") /* wwp */
   INCLUDE("If you've got a /misc, do you really need any other directories?") /* wwp */
   INCLUDE("The secret of your future is hidden in your daily routine.")
   INCLUDE("Die Zukunft ist die Gegenwart des Voraus-Schauers!") /* Peter Altenberg */
   INCLUDE("Was mich nicht umbringt, macht mich staerker.") /* Nietzsche */
   INCLUDE("Mitten im Leben sind wir vom Tod umfangen.")
   INCLUDE("Man kann nicht allen helfen, sagen manche Leute, und helfen keinem.") /* Peter Frankenfeld */
   INCLUDE("Au multo, au nenio.")
   INCLUDE("Virina rideto pli kaptas ol reto.")
   INCLUDE("Inter lupoj kriu lupe!")
   INCLUDE("Doing what's right is far more important than doing what's legal.") /* wwp */
   EXCLUDE("Let the librarian take some time off to read the books.")
   INCLUDE("Un pesimista es un optimista con experiencia.")
   EXCLUDE("404 Not Found")
   INCLUDE("Parenthesize defensively!")
   EXCLUDE("Slow down. Haste is the enemy.")
   EXCLUDE("Been there. Done that. Reincarnated.")
   INCLUDE("Help, Help, Snark in MTS!")
   INCLUDE("South Street - It's the hippest street in town.")
   EXCLUDE("Mia kolbaso havas antaunomon...")
   INCLUDE("When you starve with a tiger, the tiger starves last.")
   INCLUDE("Creativity is great, but plagiarism is faster.")
   INCLUDE("There is always one more bug.")
   EXCLUDE("Omi vias ducte a Roma.")
   EXCLUDE("Do you believe in \"echo -n foo\" or \"echo foo \\c\"?")
   EXCLUDE("Li solution del problemas sempre trova se in li exceptiones.")
   EXCLUDE("No, Thursday's out. How about never - is never good for you?")
   EXCLUDE("Building The Perfect Buddha, One Step At A Time.")
   EXCLUDE("Nope, it's true! You're soaking in it!")
   EXCLUDE("JIT meets Y2K!")
   EXCLUDE("carpe deum... god is a fish")
   EXCLUDE("carpe carpe... seize the fish")
   EXCLUDE("crape diem... bad day")
   EXCLUDE("carpe per diem... seize the check")
   EXCLUDE("carpe calypso... seize the DAY-O")
   EXCLUDE("carpe noctum... seize the night")
   EXCLUDE("You know you're too stressed when... The sun is too loud.")
   EXCLUDE("Why is \"verb\" a noun?")
   EXCLUDE("If a word is misspelled in a dictionary, how would we ever know?")
   EXCLUDE("The Chinese ideogram for trouble symbolizes two women living under one roof.")
   EXCLUDE("Why is it that the word \"gullible\" isn't in the dictionary?")
   EXCLUDE("Why isn't \"palindrome\" spelled the same way backwards?")
   EXCLUDE("Why isn't phonetic spelled the way it sounds?")
   EXCLUDE("Fortuna favorisa audacioses.")
   EXCLUDE("Yo pensa ergo yo existe.")
   EXCLUDE("Venit, videt, victet.")
   EXCLUDE("Mannes fa domes, ma fe'minas fa hemes.")
   EXCLUDE("Without him, the mission would go astray") /* from the Rimmer Song */
   EXCLUDE("More reliable than a garden Strimmer") /* from the Rimmer Song */
   EXCLUDE("He's not bald and his head doesn't glimmer") /* from the Rimmer Song */
   EXCLUDE("His command of space directives is uncanny") /* from the Rimmer Song */
   EXCLUDE("Ask Arnold, Arnold, Arnold Rimmer...") /* from the Rimmer Song */
   EXCLUDE("On ne posse sider sur du stules.")
   EXCLUDE("Errar es homan, pardonar divin.")
   EXCLUDE("Parlar es plu facil quam far.")
   EXCLUDE("Sur un rulant petre moss ne cresce.")
   EXCLUDE("Bon comensat es demi' parat.")
   EXCLUDE("Qui sempre es comensant, nequande es finient.")
   EXCLUDE("Mult homes es vocat, ma poc homes es electet.")
   EXCLUDE("Quant capes, tant opiniones!")
   EXCLUDE("It's TEOTWAWKI... It's TEOTWAWKI... It's TEOTWAWKI... And I feel fine...")
   EXCLUDE("Enlightenment is the best revenge.")
   EXCLUDE("Next time, don't forget the unicorn!")
   EXCLUDE("Warning on a Japanese food processor: \"Not to be used for the other use.\"")
   INCLUDE("An elephant is a mouse built by Microsoft.")
   INCLUDE("We all live in a yellow subroutine...")
   INCLUDE("I want to live with a synonym girl.")
   INCLUDE("Punctuality is the thief of time.")
   INCLUDE("Database? A DATABASE?? Use flat files and grep, the way God intended!")
   INCLUDE("Throwaway code never is.")
   EXCLUDE("Al chiu lau sia gusto.")
   EXCLUDE("Smoke 'em if ya got 'em.")
   INCLUDE("A man's gotta do what a man's gotta do.")
   INCLUDE("Don't make me use uppercase!")
   INCLUDE("If tin whistles are made out of tin, what do they make fog horns out of?")
   EXCLUDE("As the Jolly Green Giant once said... There's nothing like a good pea!")
   EXCLUDE("There's nothing like a good pea! Ho, ho, ho, Green Giant!")
   INCLUDE("Something really stupid is going to happen today.") /* from the Stupids */
   EXCLUDE("\"Cluck, cluck, cluck\" said the dress.") /* from the Stupids */
   INCLUDE("\"This isn't heaven.\" said Grandfather. \"This is Cleveland.\"") /* from the Stupids */
   INCLUDE("But we had fun anyway. We always do.") /* from the Stupids */
   INCLUDE("No, it's not a dream, we're stuck with it.")
   INCLUDE("I cna ytpe 300 wrods pre mniuet!!!")
   INCLUDE("Qui plus sape, plus dubitas habe.")
   INCLUDE("Das Wasser kann ohne Fische auskommen, aber kein Fisch ohne Wasser.") /* Chinesisches Sprichwort */
   INCLUDE("Was kann an einem Tag schon dran sein, der mit Aufstehn anfaengt?") /* Unbekannt */
   INCLUDE("Die grossen Gedanken kommen aus dem Herzen.") /* Luc de Clapier Vauvenargues, Philosoph und Schriftsteller */
   INCLUDE("Siesta frijole! Hasta la vista!") /* The Turner Diaries, p. 179 */
   INCLUDE("Tia estas la vivo.")
   INCLUDE("Some people drink tomato juice by choice!")
   INCLUDE("La ekstero ne chiam spegulas la internon.")
   INCLUDE("Kies panon vi manghas, ties kanton vi kantas.")
   INCLUDE("I have a quantum car. Every time I look at the speedometer I get lost.")
   INCLUDE("Gesagt, getan.") /* Pair with Dirite, farite. */
   INCLUDE("Dirite, farite.") /* Pair with Gesagt, getan. */
   EXCLUDE("road narrows")
   INCLUDE("road narrows ahead")
   EXCLUDE("Afterward they sat in a sidewalk cafe and wrote postcards to nobody.") /* The Call of the Toad, p. 246 */
   INCLUDE("A sheer drop of a hundred feet - even for a Volvo that's too much.") /* The Call of the Toad */
   INCLUDE("Love, Peace and Shonen Knife!")
   INCLUDE("Love, Peace and Shonen Knife!")
   INCLUDE("Love, Peace and Shonen Knife!")
   INCLUDE("Celebrate Life With Shonen Knife!")
   INCLUDE("Celebrating Life With Shonen Knife!")
   EXCLUDE("I like cats too. Let's exchange recipes!")
   EXCLUDE("Here I am! Now what are your other two wishes?")
   EXCLUDE("I can't remember whether I'm the good twin or the evil one.")
   EXCLUDE("Just smile and say \"Yes Master...\"")
   INCLUDE("You can fool some of the people some of the time, and that is sufficient.")
   INCLUDE("Hang up and drive!")
   EXCLUDE("I said \"no\" to drugs, but they just wouldn't listen.")
   EXCLUDE("Wenn's dich juckt, kratze dich und nicht mich!")
   INCLUDE("Die Gedanken sind frei!")
   INCLUDE("La vivo estas alia.")
   INCLUDE("Vaya con queso.")
   INCLUDE("I hear the truck, I hear the warning...") /* Shonen Knife */
   EXCLUDE("By the way, I eat chicken, too.") /* Shonen Knife */
   INCLUDE("Optimize only if it runs too slowly or does not fit. Use spaces, not tabs.")
   INCLUDE("zany zen poetry")
   INCLUDE("faster'n you can say uh-oh...") /* Red Green */
   INCLUDE("Nach dem Spiel ist vor dem Spiel.") /* Sepp Herberger */
   INCLUDE("Der Ball ist rund.") /* Sepp Herberger */
   INCLUDE("Das Spiel dauert neunzig Minuten.") /* Sepp Herberger */
   INCLUDE("An old raincoat won't ever let you down.") /* Rod Stewart */
#ifndef _MICROC_
   EXCLUDE("I may be wrong but I'm not far from it!")
   EXCLUDE("Ne penvaloras postkuri buson au virinon; baldau venos alia.")
   EXCLUDE("A hollow voice says \"Fool.\"")
   EXCLUDE("Welcome to Hell. Here is your Macintosh.")
   EXCLUDE("Emacs make easy things hard and hard things easy.")
   EXCLUDE("Two termites walk into a bar and one says, \"Is the bartender here?\"")
   EXCLUDE("Does the Little Mermaid wear an algebra?")
   EXCLUDE("Everything you need to know is on the Net. You just can't find it.")
   EXCLUDE("IT'S A FABULOUS MONSTER! the Unicorn cried out.")
   EXCLUDE("Luke, Uzu la Forton!")
   EXCLUDE("Ne estas senkosta luncho.")
   EXCLUDE("It is the way of the world.")
   EXCLUDE("It was a bright day in August, and the clocks were striking thirteen.")
   EXCLUDE("Number Five is Alive!")
   EXCLUDE("Think like a mountain.")
   EXCLUDE("Where are we going? And why are we in this handbasket?")
   EXCLUDE("Eagles may soar, but weasels don't get sucked into jet engines.")
   EXCLUDE("You never really learn to swear until you learn to drive.")
   EXCLUDE("If ignorance is bliss, then why aren't more people happy?")
   EXCLUDE("To iterate is human; to recurse, divine.")
   INCLUDE("A horse divided cannot stand.")
   INCLUDE("There's *always* room for Jello!")
   INCLUDE("Old houses have lived many lives.")
   INCLUDE("You cannot tell which way the train went by looking at the track.")
   INCLUDE("Expect a train on any track, anywhere, at any time.")
   INCLUDE("vi vi vi - The Editor Of The Beast")
   INCLUDE("Klaatu barada nikto!")
   INCLUDE("I wish I were what I was when I wanted to be what I am now.")
   INCLUDE("Don't get even - get odd!")
   INCLUDE("Welcome to the next level.")
   EXCLUDE("Merry meet, and merry part, and merry meet again.")
   INCLUDE("Weebles wobble but they don't fall down.")
   EXCLUDE("And they lived happily ever after.")
   INCLUDE("Nothing Like A Good Cup Of Coffee")
   EXCLUDE("One man's signal is another man's noise.")
   EXCLUDE("Growing old is mandatory; growing up is optional.")
   INCLUDE("The longest of journeys begins with a single URL.")
   INCLUDE("Sing Ho! for the life of a Bear!")
   INCLUDE("The life of a Repo Man is ALWAYS intense.")
   INCLUDE("It's the kind of book that makes you late for things!")
   INCLUDE("I have been to Eerie and seen the space thing.")
   INCLUDE("Eat when hungry, sleep when tired.")
   INCLUDE("O brave new world, that has such people in it!")
   INCLUDE("\"What do Jagulars do?\" asked Piglet, hoping that they wouldn't.")
   INCLUDE("All good solutions are simple, but not all simple solutions are good.")
   INCLUDE("I'm an incorrigible punster; don't incorridge me.")
   INCLUDE("Enjoy yourself. It's later than you think.")
   EXCLUDE("Let us run and tell the King!")
   INCLUDE("One peek is worth a thousand finesses.")
   INCLUDE("Time flies like an arrow. Fruit flies like a banana.")
   INCLUDE("vax vobiscum.")
   INCLUDE("When the going gets weird, the weird turn pro.")
   INCLUDE("There are days when spelling Tuesday simply doesn't count.")
   INCLUDE("There are days when spelling Tuesday simply doesn't count.")
   INCLUDE("There are days when spelling Tuesday simply doesn't count.")
   INCLUDE("Am I having fun yet?")
   INCLUDE("In VMS, as in Life, you must pass the correct number of parameters.")
   EXCLUDE("Well, isn't that special!")
   INCLUDE("10's company, 11's a crowd.")
   INCLUDE("When you get to the top of a mountain, keep climbing.")
   INCLUDE("A slow program that works is better than a fast one that doesn't.")
   INCLUDE("2+2=5 for sufficiently large values of 2.")
   INCLUDE("Life is a dream already a long time ended.")
   INCLUDE("Good programmers worry a lot.")
   INCLUDE("String together enough temporary fixes and you've GOT a permanent fix.")
   INCLUDE("If you've got a heart, then Gumby's a part of you!")
   EXCLUDE("Life is not just a game, but it is a game nonetheless.")
   INCLUDE("It's the only thing we could do. We are, after all, professionals.")
   INCLUDE("\"These go under N\" she said, while filing her nails.")
   INCLUDE("We apologize for the resumption of our usual service.")
   INCLUDE("Two wrongs don't make a right, but three lefts do.")
   INCLUDE("A procrastinator's work is never done.")
   INCLUDE("If puns are outlawed, only outlaws will have puns.")
   INCLUDE("A dirty book is seldom dusty.")
   INCLUDE("Life would be so much easier if I had the source code.")
   INCLUDE("Oh, goody!  My Alludium Q-36 Explosive Space Modulator!")
   INCLUDE("GOD IS REAL - UNLESS DECLARED INTEGER.")
   INCLUDE("I fought the lawn and the lawn won.")
   EXCLUDE("I am Homer of Borg.  Prepare to be... ooooohh, doughnuts!")
   EXCLUDE("Please return the stewardess to her fully upright and locked position.")
   EXCLUDE("These cookies don't taste anything like Girl Scouts!")
   EXCLUDE("Failure is not in falling down, but in staying down.")
   EXCLUDE("There's too much blood in my caffeine system.")
   EXCLUDE("Few women admit their age. Few men act theirs.")
   EXCLUDE("\"Bother,\" said Pooh, as he read his Compuserve bill.")
   EXCLUDE("I was born at a very early age...")
   EXCLUDE("Go that way. Really fast. If something gets in the way, turn.")
   EXCLUDE("For the next minute, try not to think of a white bear.")
   EXCLUDE("If it weren't for the last minute, nothing would ever get done.")
   EXCLUDE("To the reindeer, Santa was just a fat man with a whip.")
   EXCLUDE("If tinwhistles are made of tin, what are foghorns made of?")
   EXCLUDE("Eat, drink and be merry, for tomorrow it will probably be illegal.")
   EXCLUDE("If you're right 90% of the time, why quibble about the other 20%?")
   EXCLUDE("Klein bottle for sale ... inquire within.")
   EXCLUDE("Slowly and surely the UNIX crept up on the unsuspecting NT user ...")
   EXCLUDE("A seminar on Time Travel will be held two weeks ago.")
   EXCLUDE("He who fights & runs away will live to fight another day.")
   EXCLUDE("I've got too many hands on my time.")
   EXCLUDE("So long, and thanks for all the fish.")
   EXCLUDE("Your call will be answered in the order it was ignored.")
   EXCLUDE("tons(16); ++day; ++debt;")
   EXCLUDE("Ahead groove factor 5! Yeah!")
   EXCLUDE("Smoke me a kipper, skipper; I'll be back for breakfast.")
   EXCLUDE("Unix is the answer, but only if you phrase the question very carefully.")
   EXCLUDE("ARE YE A HUMAN BEING AND NOT A CABBAGE OR SOMETHING?")
   EXCLUDE("FIVE TONS OF FLAX!")
   EXCLUDE("Void where prohibited.")
   EXCLUDE("Some assembly required.")
   EXCLUDE("Batteries not included.")
   EXCLUDE("Use only as directed.")
   EXCLUDE("This is not an offer to sell securities.")
   EXCLUDE("Apply only to affected area.")
   EXCLUDE("Breaking seal constitutes acceptance of agreement.")
   EXCLUDE("AS SEEN ON TV!")
   EXCLUDE("Edited for television.")
   EXCLUDE("Cleaned and sanitized for your protection.")
   EXCLUDE("Don't panic! Computers know when you're scared.")
   EXCLUDE("Colorless green ideas sleep furiously.")
   EXCLUDE("Entropy isn't what it used to be.")
   EXCLUDE("On a clear disk you can seek forever.")
   EXCLUDE("$10,000 Reward - Schroedinger's Cat - Wanted Dead Or Alive")
   EXCLUDE("Even if you win the rat race you're still a rat.")
   EXCLUDE("Millihelen: amount of beauty required to launch one ship.")
   EXCLUDE("If I put water in my dog's mouth will bells ring?")
   EXCLUDE("She criticized my apartment so I knocked her flat.")
   EXCLUDE("If there were no golf balls, how would we measure hail?")
   EXCLUDE("Dr. Pavlov! Your dogs just ate the Avon lady!")
   EXCLUDE("I don't care if I AM a lemming, I'm still not going!")
   EXCLUDE("Two silkworms were having a race but it ended in a tie.")
   EXCLUDE("Pride is what we have. Vanity is what others have.")
   EXCLUDE("We have enough youth, how about a fountain of SMART?")
   EXCLUDE("happiness is a warmboot")
   EXCLUDE("We'll cross that bridge when it comes to us.")
   EXCLUDE("drawing flowcharts in the sand")
   EXCLUDE("111111111 * 111111111 = 12345678987654321")
   EXCLUDE("Hello, ball!")
   EXCLUDE("The sewers have always been good to me.")
   EXCLUDE("Fold, fold, fold!! I am folding MANY items!!") /* Zippy */
   EXCLUDE("You can only be young once, but you can be immature forever!")
   EXCLUDE("He who hesitates is probably right.")
   EXCLUDE("pli bone malfrue ol neniam!")
   EXCLUDE("plu bone tarde kam nultempe!")
   EXCLUDE("I'd rather be rich than stupid.")
   EXCLUDE("Stop. Listen.")
   EXCLUDE("In some cultures what I do would be considered normal.")
   EXCLUDE("To understand all is to fear all.")
   EXCLUDE("The X which can be Y is not the true X.")
   EXCLUDE("Yes, I think I shall express the accusative case by a prefix.")
   EXCLUDE("Iron Duke. Iron Duke. This is Pawn Sacrifice. Come in, please.")
   EXCLUDE("Everybody wants a rock to wind a piece of string around.")
   EXCLUDE("I brake and do not brake for Buddha.")
   EXCLUDE("Do people with psychic powers get nostalgic about next week?")
   EXCLUDE("Why is phonetic not spelt the way it sounds?")
   EXCLUDE("leave the nite lite on inside the birdhouse in your soul")
   EXCLUDE("Attaboy, Luther!")
   EXCLUDE("Is this a great time or what?")
   EXCLUDE("It is a newt, and it does not seem to be getting better.")
   EXCLUDE("La unesma pazo es la maxim desfacila.")
   EXCLUDE("Ne permisez pasinta falio preventar futura suceso.")
   EXCLUDE("Akti prima plu prima ra.")
   EXCLUDE("Nuli-ra acide per fortuna.")
   EXCLUDE("U boni-ra es u non-ami de u maxi-boni-ra.")
   EXCLUDE("Aprende te es silento. Lase tu qieta menta akusti e sorbe.")
   EXCLUDE("U ra habe kompleti kron tu pote lase id existe.")
   EXCLUDE("Un ergo es filo; qi gene ge-vide.")
   INCLUDE("WARNING: Do not look into laser beam with remaining eyeball.")
   INCLUDE("Check for toilet paper *before* sitting down.")
   INCLUDE("Ensign Fodder, report to transporter for away team duty.")
   EXCLUDE("If you can't say something nice, say something surreal.")
   INCLUDE("I have seen the evidence. I want DIFFERENT evidence!")
   INCLUDE("Taxation WITH representation isn't so hot either.")
   EXCLUDE("Excuse me, Chief, my shoe is ringing.")
   INCLUDE("Did you expect mere proof to sway my opinion?")
   INCLUDE("One man's theology is another man's belly laugh.")
   INCLUDE("When cryptography is outlawed, bqyl bscnnjf sdvf dasr cslmnpl!")
   INCLUDE("If at first you don't succeed, redefine success.")
   INCLUDE("I don't cheat, I play by the extended rules.")
   INCLUDE("Life is like an analogy.")
   INCLUDE("I have a mind like a steel... uh... thingy.")
   INCLUDE("If you are seen fixing it, you will be blamed for breaking it.")
   INCLUDE("It's easier to obtain forgiveness than permission.")
   INCLUDE("MOUNT TAPE U1439 ON B3, NO RING")
   INCLUDE("Never put off till tomorrow what you can put off forever.")
   INCLUDE("No amount of genius can overcome a preoccupation with detail.")
   INCLUDE("To err is human, to admit it is not.")
   INCLUDE("Earth is like a great big funhouse without the fun.")
   INCLUDE("That, and another piece of coffee cake, should do the trick.")
   EXCLUDE("i ching, you ching, we all ching...") /* hillary! */
   INCLUDE("Oh, wow! Look at the moon!")
   INCLUDE("The older a man gets, the farther he had to walk to school as a boy.")
   INCLUDE("Smile, they said, life could be worse... So I did... And it was.")
   EXCLUDE("If you're not confused, you're not paying attention.")
   INCLUDE("He who hesitates is last.")
   INCLUDE("As you read the scroll, it vanishes...")
   INCLUDE("The ships hung in the sky in much the same way that bricks don't.")
   INCLUDE("And now for something completely different.")
   INCLUDE("Back when I was a boy, we carved our own ICs out of wood.")
   INCLUDE("But once you are real, you can't become unreal again.")
   INCLUDE("It's a beautiful day in the neighborhood.")
   INCLUDE("The trouble with a kitten is that eventually it's a cat.")
   INCLUDE("The novices know the rules, the experienced know the exceptions.")
   INCLUDE("The novices know the rules, the experienced know the exceptions.")
   INCLUDE("The novices know the rules, the experienced know the exceptions.")
   INCLUDE("And now, Watson, let us have a little stroll round in the sunshine.")
   INCLUDE("Come, Watson, come! The game is afoot!")
   INCLUDE("Reality was never enough, there was need of magic.")
   INCLUDE("Znqr lbh ybbx!") /* rot13, made you look! */
   INCLUDE("You know, Beavis, you need things that suck, to have things that are cool.")
   INCLUDE("Vivu longe kaj prosperu!")
   EXCLUDE("Whenever you're in a hurry, it's best to slow down.")
   INCLUDE("Wherever I am, there's always Pooh, there's always Pooh and Me!")
   EXCLUDE("Stand back! I've got a /dev/null and I'm not afraid to use it...")
   INCLUDE("Everything's regular if the rules are complicated enough...")
   INCLUDE("Everything's regular if the rules are complicated enough...")
   EXCLUDE("If it's worth doing, somebody would have done it already.")
   EXCLUDE("Rain on a tin roof sounds like a drum...")
   EXCLUDE("He laughed at accidental sirens that broke the evening gloom") /* Bowie */
   EXCLUDE("Let me collect dust. - I wish someone would phone...") /* Bowie */
   EXCLUDE("Freak out in the moonage daydream oh! yea!") /* Bowie */
   EXCLUDE("Hey, that's far out so you heard him too!") /* Bowie */
   EXCLUDE("Switch on the TV we may pick him up on channel two") /* Bowie */
   EXCLUDE("Look out your window I can see his light") /* Bowie */
   EXCLUDE("If we can sparkle he may land tonight") /* Bowie */
   INCLUDE("Planet earth is blue and there's nothing I can do...") /* Bowie */
   EXCLUDE("Diamond Dogs are poachers, and they hide behind trees") /* Bowie */
   EXCLUDE("They got a message from the action man") /* Bowie */
   EXCLUDE("I'm happy - hope you're happy too") /* Bowie */
   EXCLUDE("You better not mess with major tom") /* Bowie */
   EXCLUDE("Put on your red shoes and dance the blues") /* Bowie */
   EXCLUDE("A crack in the sky and a hand reaching down to me") /* Bowie */
   INCLUDE("Oh man! look at those cavemen go") /* Bowie */
   INCLUDE("Is there life on Mars?") /* Bowie */
   INCLUDE("'cause I'd rather stay here with all the madmen") /* Bowie */
   INCLUDE("And I looked and frowned and the monster was me.") /* Bowie */
   INCLUDE("We're just older children, after all") /* Bowie */
   EXCLUDE("We passed upon the stair, we spoke of was and when") /* Bowie */
   INCLUDE("Oh no - not me - I never lost control") /* Bowie */
   INCLUDE("I laughed and shook his hand, and made my way back home") /* Bowie */
   INCLUDE("I searched for form and land, for years and years I roamed") /* Bowie */
   EXCLUDE("I gazed a gazely stare at all the millions here") /* Bowie */
   INCLUDE("We must have died alone, a long long time ago") /* Bowie */
   EXCLUDE("She ruled the toads of the short forest and every newt in Idaho...") /* Zappa */
   EXCLUDE("Is that a real poncho?") /* Zappa */
   INCLUDE("Si hoc legere scis nimium eruditionis habes.")
   INCLUDE("It's the RINSE cycle!! They've all ignored the RINSE CYCLE!!") /* Zippy */
   INCLUDE("That government is best which governs somebody else.")
   INCLUDE("Quit thinking about koans. Learn how to go to sleep and wake up.")
   INCLUDE("Quick! I need a computer, a compiler, Vim and a beer!")
   EXCLUDE("A Real Programmer can write FORTRAN programs in any language.")
   INCLUDE("Never argue about religion, politics, or text editors.")
   EXCLUDE("Common sense is what tells you that the world is flat.")
   INCLUDE("vi - the ubiquitous editor")
   INCLUDE("A virtuous life is its own punishment.")
   INCLUDE("Although the moon is smaller than the earth, it is farther away.")
   EXCLUDE("It is impossible for an optimist to be pleasantly surprised.")
   INCLUDE("Call on God, but row away from the rocks.")
   INCLUDE("Do you know where your towel is?")
   INCLUDE("Inside every large program is a small program struggling to get out.")
   INCLUDE("If you're not part of the solution, then you're part of the precipitate.")
   INCLUDE("Oh, no. Not again.")
   INCLUDE("He who laughs last probably didn't get the joke.")
   INCLUDE("Always state the opinions on which your facts are based.")
   INCLUDE("Always state the opinions on which your facts are based.")
   EXCLUDE("The Theorem Theorem: If if, then then.")
   INCLUDE("The attacker must vanquish; the defender need only survive.")
   INCLUDE("The door is the key.")
   INCLUDE("Don't put off until runtime what you can compile today!")
   INCLUDE("It's a fast program except when running on a half-fast computer.")
   INCLUDE("Look before you loop!")
   EXCLUDE("Why did the chicken cross the Moebius Strip?")
   INCLUDE("How did the chicken cross the Moebius Strip?")
   EXCLUDE("Power corrupts; absolute power is kind of neat.")
   EXCLUDE("Time is nature's way of keeping everything from happening at once.")
   EXCLUDE("Take time to smell the roses and eventually you'll inhale a bee.")
   EXCLUDE("To be Frank, monsieur, I'd have to change my name.")
   INCLUDE("I spilled spot remover on my dog... now he's gone.")
   EXCLUDE("If your legs bent the other way, what would a chair look like?")
   INCLUDE("There is a Madness to my Method!")
   EXCLUDE("uniquely maladjusted, but fun to be with!")
   INCLUDE("Every silver lining has a cloud.")
   INCLUDE("Don't let the sunshine spoil your rain.")
   INCLUDE("I'd rather add life to my years than years to my life!")
   INCLUDE("OH JOY!")
   INCLUDE("When catapulted, you've nothing left to do but fly.") /* Catapult */
   EXCLUDE("It was a wild and stormy night on the West Coast of Scotland.")
   INCLUDE("In those times one radio speaker per car seemed sufficient.")
   EXCLUDE("He who lives by the sword dies by the crossbow.")
   INCLUDE("pi=3, for small values of pi and large values of 3.")
   EXCLUDE("Slow down and focus on getting things right!")
   INCLUDE("A basis in reality. That's good.") /* Where The Buffalo Roam */
   INCLUDE("It's all right. I'm in control. I'm not sure about these people though.") /* Where The Buffalo Roam */
   INCLUDE("WARNING: Dates in calendar are closer than they appear.")
   INCLUDE("When you are not looking at this sentence, it is in Esperanto.")
   INCLUDE("Esperanto - La Lingvo Internacia")
   INCLUDE("Esperanto parolata.")
   INCLUDE("Ido es klefo qua apertas la pordo a plu vasta mondo.")
   INCLUDE("Ho, Urso, Winnie la Pu! Kiel multe mi amas vin!")
   INCLUDE("You can't grep dead trees!")
   INCLUDE("Eppur si muove...")
   EXCLUDE("It lacks the monosyllabic nature.")
   EXCLUDE("Akvo silenta subfosas la bordon.")
   EXCLUDE("Al fish' kuirita jam akvo ne helpos.")
   EXCLUDE("Al la afero!")
   INCLUDE("Alia tempo, aliaj moroj.")
   INCLUDE("Antaue kion vi devas, poste kion vi volas.")
   EXCLUDE("Atentu!")
   INCLUDE("Chio havas finon.")
   INCLUDE("Dek fojojn mezuru, unu fojon detranchu!")
   INCLUDE("Du militas - tria profitas.")
   INCLUDE("Ech bagatelo povas servi al celo.")
   INCLUDE("En arbaro sidis kaj arbojn ne vidis.")
   INCLUDE("Estinta amiko estas plej danghera malamiko.")
   EXCLUDE("Ghi estas nek viando nek fisho.")
   EXCLUDE("Jen staras la bovoj antau la monto!")
   INCLUDE("Kia demando, tia respondo.")
   EXCLUDE("Kiam nokto vualas, chiuj koloroj egalas.")
   INCLUDE("Kie lumo ekzistas, ankau ombro trovighas.")
   EXCLUDE("Kiel akirite, tiel perdite.")
   INCLUDE("Kiu batas edzinon, tiu vundas sin mem.")
   EXCLUDE("Kiu perdis la kapon, ne bezonas jam chapon.")
   EXCLUDE("Kiu semas venton, rikoltos fulmotondron.")
   EXCLUDE("La muro havas orelojn.")
   EXCLUDE("Laudu la maron, sed restu sur tero.")
   EXCLUDE("Lia cerbo iris promeni.")
   INCLUDE("Lupo lupon ne manghas.")
   INCLUDE("Magia rondo.")
   EXCLUDE("Malaperis, kiel vaporo.")
   EXCLUDE("Manko de oro ne estas malhonoro.")
   INCLUDE("Matena horo estas plena de oro.")
   INCLUDE("Ne chio brilanta estas diamanto.")
   INCLUDE("Ne ekzistas regulo sen escepto.")
   INCLUDE("Ne kaptita - ne punita.")
   EXCLUDE("Ne veku malfelichon, kiam ghi dormas.")
   EXCLUDE("Ni laboru kaj esperu.")
   INCLUDE("Pli bone estas reiri, ol perdi la vojon.")
   INCLUDE("Pli bone malfrue ol neniam.")
   INCLUDE("Por patrino ne ekzistas infano malbela.")
   EXCLUDE("Post brua vento subita silento.")
   INCLUDE("Printempo semas, autuno rikoltas.")
   EXCLUDE("Prokrastita ne estas perdita.")
   INCLUDE("Sagha hundo post la vundo.")
   INCLUDE("Sen eliro.")
   EXCLUDE("Suspekto pruvon ne egalas.")
   INCLUDE("Shlosilo uzata ruston ne konas.")
   EXCLUDE("Unu amiko malnova pli valoras ol du novaj.")
   INCLUDE("Make it up as you go along. Everybody else does.")
   INCLUDE("chi tie kaj nun.")
   INCLUDE("Honesty is doing the right thing when nobody's looking.")
   INCLUDE("A good lawyer knows the law. A great lawyer knows the judge.")
   INCLUDE("Bonvolu sendi por la pordisto, estas rano en mia bideo!") /* Red Dwarf! */
   INCLUDE("It's cold outside, there's no kind of atmosphere...") /* Red Dwarf */
   INCLUDE("I want to lie shipwrecked and comatose, drinking fresh mango juice...") /* Red Dwarf */
   INCLUDE("Fun, fun, fun in the sun, sun, sun") /* Red Dwarf */
   INCLUDE("There are problems that can't be solved by triangles.") /* Pete & Pete */
   INCLUDE("If you need to load, or unload, go to the White Zone.")
   INCLUDE("What does a glove fit like?")
   INCLUDE("How do you know when you've run out of invisible ink?")
   EXCLUDE("That was no ordinary coconut.")
   EXCLUDE("Who are you going to believe, me or your own eyes?")
   INCLUDE("Don't ask a barber whether you need a haircut.")
   INCLUDE("NT - The power of Windows, the simplicity of Unix.")
   INCLUDE("You may not like kudzu at first, but it will grow on you...")
   INCLUDE("Watch out for off-by-one errors.")
   INCLUDE("You are standing at the end of a road before a small brick building.")
   INCLUDE("You are inside a building, a well house for a large spring.")
   INCLUDE("Set into the dirt is a strong steel grate mounted in concrete.")
   INCLUDE("A low crawl over cobbles leads inward to the west.")
   EXCLUDE("You can't get by the snake.")
   INCLUDE("You are in a maze of twisty little URLs, all alike...")
   INCLUDE("You are in a maze of twisty little passages, all alike.")
   INCLUDE("You are in a maze of twisty little passages, all different.")
   EXCLUDE("You are in a little maze of twisty passages, all different.")
   EXCLUDE("You are in a twisty little maze of passages, all different.")
   EXCLUDE("You are in a twisty maze of little passages, all different.")
   EXCLUDE("You are in a maze of twisty little subdirectories, all alike.")
   EXCLUDE("You are in a maze of twisting little passages, all different.")
   EXCLUDE("You are in a twisting maze of little passages, all different.")
   EXCLUDE("You are in a twisting little maze of passages, all different.")
   EXCLUDE("You are in a little twisty maze of passages, all different.")
   EXCLUDE("You are in a maze of little twisting passages, all different.")
   EXCLUDE("You are in a maze of little twisty passages, all different.")
   EXCLUDE("You are in a little maze of twisting passages, all different.")
   EXCLUDE("You're in a small chamber lit by an eerie green light.")
   INCLUDE("You are at Witt's End. Passages lead off in ALL directions.")
   EXCLUDE("Do not disturb the dwarves!")
   EXCLUDE("A faint rumbling noise can be heard in the distance.")
   INCLUDE("There is a shiny brass lamp nearby.")
   INCLUDE("A cheerful little bird is sitting here singing.")
   INCLUDE("The way north is barred by a massive, rusty, iron door.")
   INCLUDE("A huge green fierce snake bars the way!")
   EXCLUDE("A crystal bridge now spans the fissure.")
   EXCLUDE("The crystal bridge has vanished!")
   EXCLUDE("Stop! Pay troll!")
   EXCLUDE("The troll steps out from beneath the bridge and blocks your way.")
   EXCLUDE("This is not the maze where the pirate leaves his treasure chest.")
   EXCLUDE("The grate is now unlocked.")
   EXCLUDE("The shadowy figure seems to be trying to attract your attention.")
   EXCLUDE("It is now pitch dark. If you proceed you will likely fall into a pit.")
   INCLUDE("Nothing happens.")
   INCLUDE("Twice as much nothing happens.")
   INCLUDE("You can make the passages look less alike by dropping things.")
   EXCLUDE("You can't get there from here.")
   EXCLUDE("If you want to end your adventure early, say \"QUIT\".")
   EXCLUDE("Do you need help getting out of the maze?")
   EXCLUDE("All of Adventuredom gives tribute to you, Adventure Grandmaster!")
   EXCLUDE("Call the Request Line and ask for the song they just played.")
   INCLUDE("Whatever you wish for me, may you have twice as much.")
   EXCLUDE("Yo Ho Lord Helmet!") /* Spaceballs */
   EXCLUDE("Yes, I always have coffee when I watch radar, you know that!") /* Spaceballs */
   EXCLUDE("Funny. She doesn't look Druish.") /* Spaceballs */
   EXCLUDE("We're gonna have to go right to.... Ludicrous Speed!") /* Spaceballs */
   EXCLUDE("May the Schwartz be with you!") /* Spaceballs */
   INCLUDE("What the hell.... it worked on Star Trek!") /* Spaceballs */
   INCLUDE("This is much too early! Prepare to fast forward!") /* Spaceballs */
   INCLUDE("How do \"Keep off the grass\" signs get where they are?")
   INCLUDE("If you ate pasta and antipasta, would you still be hungry?")
   INCLUDE("If you try to fail, and succeed, which have you done?")
   INCLUDE("Think big! You can't cross a chasm in two small jumps.")
   EXCLUDE("If the #2 pencil is the most popular, why is it still #2?")
   EXCLUDE("As God as my witness, I thought turkeys could fly.") /* WKRP */
   EXCLUDE("No-funktio - Ne pote detekti u defekti.")
   INCLUDE("La plejbono estas la malamiko de la bono.")
   INCLUDE("Chapter 4: In which Eeyore loses a tail and Pooh finds one ")
   INCLUDE("Chapter 6: In which Eeyore has a birthday and gets two presents ")
   EXCLUDE("Chapter 9: In which Piglet is entirely surrounded by water ")
   INCLUDE("Chapter 10: In which Christopher Robin gives a Pooh Party, and we say good-bye.")
   INCLUDE("Chapter 2: In which Tigger comes to the Forest and has breakfast ")
   EXCLUDE("Chapter 4: In which it is shown that Tiggers don't climb trees ")
   INCLUDE("Chapter 6: In which Pooh invents a new game and Eeyore joins in ")
   INCLUDE("Chapter 7: In which Tigger is unbounced ")
   INCLUDE("Chapter 8: In which Piglet does a very grand thing ")
   INCLUDE("The world is coming to an end. Please log off.")
   EXCLUDE("I started out with nothing and still have most of it left.")
   EXCLUDE("The early bird may get a worm, but the *second* mouse gets cheese.")
   EXCLUDE("la lojban po'u le logji bangu") /* Lojban - The Logical Language */
   EXCLUDE("e'osai ko sarji la lojban.") /* Please! Support Lojban */
   EXCLUDE("be in with the in crowd.")
   EXCLUDE("Don't bother me. I'm living happily ever after.")
   EXCLUDE("If you'd only use your magic powers for good instead of evil...")
   EXCLUDE("A PBS mind in an MTV world.")
   EXCLUDE("Abusus non tollit usum.") /* Wrong use does not take away proper use. (Just because something is abused, it should not be taken away from those who use it properly.) --Legal */
   EXCLUDE("Ad experimentum.") /* As an experiment. */
   EXCLUDE("Amat victoria curam.") /* Victory favors those who take pains (lit., victory loves care). --Roman proverb */
   EXCLUDE("Ars perdita.") /* A lost art. */
   EXCLUDE("Ave, imperator, morituri te salutamus.") /* Hail, Caesar; we who are about to die salute you. */
   EXCLUDE("Bonum, verum, pulchrum.") /* The good, the true, the beautiful. */
   EXCLUDE("Carpe diem, quam minimum credula postero.") /* Seize the day, trusting as little as possible in the future. --Horace, Odes I.11 */
   EXCLUDE("Casta fuit, domum servavit, lanam fecit.") /* She was faithful to her husband, she looked after the home, she spun wool. --A Roman woman's tombstone */
   EXCLUDE("Ceteris paribus.") /* Other things being equal. */
   EXCLUDE("Credo quia absurdum est.") /* I believe because it is absurd. --Tertullian */
   EXCLUDE("Damnant quod non intellegunt.") /* They condemn what they do not understand. */
   EXCLUDE("Diverte a malo, et fac bonum.") /* Turn from evil, and do good. --St. Benedict */
   INCLUDE("Docent omnia.") /* Everything teaches. */
   EXCLUDE("Dulce est dissipere in loco.") /* It is pleasant to tarry on a topic. */
   EXCLUDE("Dura est ovicipitum via.") /* The way of the egghead is hard. --Adlai Stevenson, 1954 */
   EXCLUDE("Entia non sunt multiplicanda praeter necessitatem.") /* Entities are not to be multiplied except for necessity. (Ockham's Razor) --William of Ockham */
   EXCLUDE("Ex caerulo.") /* Out of the blue. */
   EXCLUDE("Experientia docet.") /* Experience teaches. --Tacitus */
   EXCLUDE("Forsan et hae olim meminisse iuvabit.") /* Some day perhaps it will be pleasing to remember these things too. --Vergil, Aeneid */
   EXCLUDE("Graecum est, non potest legi.") /* It is Greek; it can't be understood. */
   EXCLUDE("Haec satis sint.") /* Let these things be sufficient (of a list of examples). */
   EXCLUDE("Hic et nunc.") /* Here and now. */
   EXCLUDE("Homo proponit, sed deus disponit.") /* Man proposes, but God disposes. --Thomas a Kempis, De Imitatione Christi, 1:19:9 */
   EXCLUDE("Horam sole nolente nego.") /* I deny the hour when the sun is unwilling. --Motto on a sundial */
   EXCLUDE("Illegitimis nil carborundum.") /* Don't let the bastards grind you down. --From the mediaeval jingle, "Si te dominorum vis/Facit furibundum,/ Dico "illegitimis Nichil carborundum" */
   EXCLUDE("In medias res.") /* Into the middle of things. --Horace */
   EXCLUDE("In silvam ne ligna feras.") /* Don't carry logs into the forest. ("Don't carry coals to Newcastle"). --Horace, Satirae, 1:10:34 */
   EXCLUDE("Inveniam viam aut faciam.") /* I shall find a way, or I shall make one. --Peary, discoverer of the North Pole */
   EXCLUDE("Ipsa scienta potestas est.") /* For knowledge itself is power. --Bacon, Meditationes Sacrae, De Haeresibus */
   EXCLUDE("Ita vita.") /* So goes life. --Sundial motto */
   EXCLUDE("Lapsus calami.") /* A slip of the pen. */
   EXCLUDE("Latet anguis in herba.") /* A snake lies in the grass. */
   EXCLUDE("Lex mala, lex nulla.") /* A bad law (is) no law. --St. Thomas Aquinas */
   EXCLUDE("Locus standi.") /* A place to stand. */
   EXCLUDE("Luminis indicium est haec umbra inferna superni.") /* The indication of light above is this shadow below. --Herbert H. Huxley, Wolfson College, Cambridge, England, translated for an inscription on a sundial for Dr. Henry I. Bowditch */
   EXCLUDE("Mala herba cito crescit.") /* A weed grows quickly. */
   INCLUDE("Modificatis modificandis.") /* What was to be modified having been modified. */
   EXCLUDE("Mutatis mutandis.") /* What was to be changed having been changed. */
   EXCLUDE("Ne supra crepidam sutor iudicaret.") /* Let a cobbler not judge beyond a sandal. ("Stick with what you know.") --Apelles, as quoted by Pliny the Elder */
   INCLUDE("Necessitas non subditur legi.") /* Necessity does not submit to the law. --St. Thomas Aquinas, Summa Theologica, Ia IIae, Qu. 96, A. 6 */
   EXCLUDE("Nemo dat quod non habet.") /* No one gives what he does not have. --Legal */
   EXCLUDE("Nemo liber est qui corpori servit.") /* No one is free who is a slave to his body. --Seneca */
   EXCLUDE("Nemo malus nisi probetur.") /* No one is (to be considered) evil unless it should be proved. ("Innocent until proven guilty.") */
   EXCLUDE("Nil desperandum.") /* Nothing is to be despaired of. ("Never despair.") */
   EXCLUDE("Nitor in adversum.") /* I struggle against adversity. */
   EXCLUDE("Nolo episcopari.") /* I do not want to be a bishop. ("I do not choose to run.") --St. Ambrose */
   EXCLUDE("Non ad rem.") /* Not to the point. --Legal */
   EXCLUDE("Non est arbor solida nec fortis nisi in quam frequens ventus incursat.") /* A tree is not sturdy or strong unless the wind has frequently buffeted it. --Seneca, De Providentia, 4:16 */
   EXCLUDE("Non numero horas nisi serenas.") /* I do not count the hours unless (they are) sunny. --Motto on a sundial */
   EXCLUDE("Non omnes qui habent citharam sunt citharoedi.") /* Not all who own a harp are harpists. --Varro, de Re Rustica, 2:1:3 */
   INCLUDE("Non omnis moriar.") /* I shall not completely die. --Horace, Odes */
   EXCLUDE("Non omnia possumus omnes.") /* Everyone cannot do everything. */
   EXCLUDE("Non semper ea sunt quae videntur.") /* Things are not always as they seem. */
   EXCLUDE("Non enim tam praeclarum est scire latine quam turpe nescire.") /* It is not so much excellent to know [good] Latin, as it is a shame not to know it. --Cicero, Brutus 37:140 */
   EXCLUDE("Nullius in verba.") /* (Rely) on the words of no one. ("Don't take anybody's word for it.") --Horace */
   INCLUDE("Nullus est instar domus.") /* There is no place like home. */
   INCLUDE("O felix culpa.") /* O happy mistake. (Of the good that comes from a mistake.) */
   EXCLUDE("O tempora, o mores.") /* O times, o customs. --Cicero, Oratio in Catilinam I */
   EXCLUDE("Omne initium est difficile.") /* Every beginning is difficult. */
   EXCLUDE("Omnia fausta ominamur.") /* We predict all things (to turn out) well. */
   EXCLUDE("Optimus magister bonus liber.") /* The best teacher is a good book. */
   EXCLUDE("Pax et bonum!") /* Peace and salvation! --Franciscan greeting */
   EXCLUDE("Pecunia in arboribus non crescit.") /* Money does not grow on trees. */
   EXCLUDE("Plusve minusve.") /* More or less. */
   EXCLUDE("Post tenebras lux.") /* After the darkness (comes) light. */
   EXCLUDE("Potius sero quam numquam.") /* Better late than never. */
   EXCLUDE("Prima sibi charitas.") /* First, charity to oneself. ("Charity begins at home.") */
   EXCLUDE("Primum non nocere.") /* The first thing is to do no harm. --Hippocratic Oath */
   EXCLUDE("Puris omnia pura.") /* To the pure all things are pure. */
   EXCLUDE("Qui desiderat pacem praeparet bellum.") /* Let him who wishes for peace prepare for war. --Vegetius */
   EXCLUDE("Qui parce seminat, parce et metit.") /* Who sows sparingly also reaps sparingly. */
   EXCLUDE("Quid plura?") /* What more? */
   EXCLUDE("Quis custodiet custodes ipsos.") /* Who will guard the guards themselves? --Juvenal */
   EXCLUDE("Quo vadis, et ad quid?") /* Whither do you go, and why? --St. Ignatius */
   EXCLUDE("Repetitio mater memoriae.") /* Repetition (is) the mother of memory. */
   EXCLUDE("Repetitio est mater studiorum.") /* Repetition is the mother of studies. */
   EXCLUDE("Res ipsa loquitur.") /* The matter speaks for itself. --Cicero, Pro Milone, 53 */
   EXCLUDE("Res loquitur ipsa.") /* The matter speaks for itself. --Cicero, Pro Milone, 53 */
   EXCLUDE("Semper et ubique.") /* Always and everwhere. */
   INCLUDE("Semper ubique idem.") /* Always (and) everywhere the same. */
   EXCLUDE("Sic passim.") /* Thus everywhere (in textual annotation). */
   EXCLUDE("Sol omnibus lucet.") /* The sun shines upon us all. --Petronius */
   EXCLUDE("Sub silentio.") /* In silence. */
   EXCLUDE("Sub secreto.") /* In secret. */
   EXCLUDE("Suum cuique pulchrum est.") /* To each his own (is beautiful). --Cicero */
   EXCLUDE("Tabula rasa in qua nihil est scriptum.") /* A clean slate on which nothing has been written. --Aristotle, De Anima, 3:4, as quoted by St. Thomas Aquinas, Summa Theologica */
   INCLUDE("Tempora mutantur, nos et mutamur in illis.") /* Times change, and we change with them. --Attributed to John Owen, ob. 1622 */
   EXCLUDE("Tempus neminem manet.") /* Time waits for no man. */
   EXCLUDE("Similia similibus quod ante.") /* Similar things for similar things which (were used) before. A principle of mediaeval medicine. "The hair of the dog that bit you." */
   EXCLUDE("Tot populorum discordes ferasque linguas sermonis commercio contraxit.") /* (Latin) united through the fellowship of language the discordant and wild tongues of so many peoples. --Pliny the Elder, Historia Naturalis, 3:6:2 */
   EXCLUDE("Ubi solitudinem faciunt, pacem appellant.") /* They make a wilderness and call it peace. --Tacitus */
   EXCLUDE("Unum necessarium.") /* The one necessity. */
   EXCLUDE("Vadit et venit.") /* It goes, and it comes. --Thomas a Kempis, De Imitatione Christi, 3:6:11 */
   EXCLUDE("Via media.") /* The middle way (i.e., between extremes). */
   EXCLUDE("Vide et crede.") /* See and believe. ("Seeing is believing.") */
   EXCLUDE("Vincit omnia amor.") /* Love conquers all. */
   EXCLUDE("Vincit omnia labor.") /* Work conquers all. */
   EXCLUDE("Vincit omnia veritas.") /* Truth conquers all. */
   EXCLUDE("Virtus in medio stat.") /* Virtue stands in the middle (i.e., between two extremes). */
   EXCLUDE("Vita sine libris mors est.") /* Life without books is death. */
   EXCLUDE("Vivat atque floreat.") /* May it live and prosper. */
   EXCLUDE("Vivat rex.") /* Long live the king. */
   EXCLUDE("Vive et vivas.") /* Live and let live. */
   EXCLUDE("Better living through denial.")
   EXCLUDE("Nimm, was du magst; iss, was du nimmst.") /* Take all you want, eat all you take. */
   INCLUDE("Aller Anfang ist schwer.") /* All beginning is difficult. */
   INCLUDE("Aus Schaden wird man klug.") /* You learn from your mistakes. */
   INCLUDE("Durch Schaden wird man klug.") /* You learn from your mistakes. */
   INCLUDE("Eigner Herd ist Goldes wert.") /* There's no place like home. */
   INCLUDE("Eile macht Weile.") /* Haste makes waste. */
   EXCLUDE("Einigkeit macht stark.") /* There is strength in unity. */
   INCLUDE("Ende gut, alles gut.") /* All's well that ends well. */
   INCLUDE("Erst kommt das Fressen, dann die Moral.") /* The belly has no conscience. */
   EXCLUDE("Frisch gewagt ist halb gewonnen.") /* Nothing ventured, nothing gained. */
   EXCLUDE("Geld verdirbt den Charakter.") /* Money ruins character. */
   INCLUDE("Hunger ist der beste Koch.") /* Anything tastes good when you are hungry. */
   EXCLUDE("Im Wein ist Wahrheit.") /* In vino veritas. */
   EXCLUDE("Irren ist menschlich.") /* To err is human... */
   EXCLUDE("Jedes Ding hat seine zwei Seiten.") /* There are two sides to everything. */
   INCLUDE("Keine Antwort ist auch eine Antwort.") /* No answer is also an answer. */
   EXCLUDE("Morgen, morgen, nur nicht heute, sagen alle faulen Leute.") /* Don't put off till tomorrow, what you can do today. */
   EXCLUDE("Verschiebe nicht auf morgen, was du heute kannst besorgen.") /* Don't put off till tomorrow, what you can do today. */
   EXCLUDE("Schweigen ist Gold.") /* Silence is golden. */
   EXCLUDE("Schuster, bleib bei deinen Leisten.") /* Shoemaker stick to your last. */
   EXCLUDE("Sicher ist sicher.") /* Don't rock the boat. */
   INCLUDE("So ist das Leben!") /* Such is life! */
   EXCLUDE("Was Du heute kannst besorgen, verschiebe nicht auf morgen.") /* Don't put off till tomorrow, what you can do today. */
   EXCLUDE("Was ich nicht weiss, macht mir nicht heiss.") /* What you don't know won't hurt you. */
   EXCLUDE("Was man hat, das hat man.") /* What you've got, you've got. */
   EXCLUDE("Wer im Glashaus sitzt soll nicht mit Steinen werfen.") /* People who live in glass houses shouldn't throw stones. */
   INCLUDE("Wer rastet, der rostet.") /* Use it or lose it. */
   EXCLUDE("Wie du mir, so ich dir.") /* Tit for tat. */
   EXCLUDE("Wie gewonnen, so zeronnen.") /* Easy come, easy go. */
   INCLUDE("Wo ein Wille ist, da ist auch ein Weg.") /* Where there's a will, there's a way. */
   EXCLUDE("Wo mir's gut geht, ist mein Vaterland.") /* Ubi bene, ibi patria. */
   EXCLUDE("Zeige mir Deine Freunde und ich sage Dir wer Du bist.") /* A man is known by the friends he keeps. */
   INCLUDE("Alles hat seine Zeit!")
   EXCLUDE("Alte Liebe rostet nicht!")
   EXCLUDE("Bei Nacht sind alle Katzen grau!")
   INCLUDE("Besser etwas, als gar nichts!")
   EXCLUDE("Der Mensch denkt und Gott lenkt!")
   EXCLUDE("Ein gutes Gewissen ist ein sanftes Ruhekissen!")
   EXCLUDE("Einmal ist keinmal!")
   EXCLUDE("Irren ist menschlich!")
   EXCLUDE("Man ist nur einmal jung!")
   INCLUDE("Morgen ist auch noch ein Tag!")
   EXCLUDE("Morgen, morgen, nur nicht heute, sagen alle faulen Leute!")
   INCLUDE("Morgenstund hat Gold im Mund!")
   INCLUDE("Rasten heisst Rosten!")
   EXCLUDE("Reden ist Silber, Schweigen ist Gold!")
   EXCLUDE("Verschiebe nicht auf morgen, was du heute kannst besorgen!")
   INCLUDE("Vorsicht ist besser als Nachsicht!")
   EXCLUDE("Wer im Glashaus sitzt, soll nicht mit Steinen werfen!")
   INCLUDE("Wer nicht wagt, der nicht gewinnt!")
   EXCLUDE("Wer zuerst kommt, mahlt zuerst!")
   EXCLUDE("Wie man sich bettet, so liegt man!")
   EXCLUDE("Der Metzger metzt das Metzgermesser, das Metzgermesser metzt der Metzger.")
   EXCLUDE("Esel fressen Nesseln nicht- Nesseln fressen Esel nicht.")
   EXCLUDE("Es klapperten die Klapperschlangen, bis ihre Klappern schlapper klangen.")
   EXCLUDE("Fritz Schmitt spricht schlecht Spanisch.")
   EXCLUDE("In Ulm und um Ulm und um Ulm herum.")
   EXCLUDE("Schwarze Katzen kratzen mit schwarzen Tatzen.")
   EXCLUDE("Sieben Schneeschipper schippen mit sieben Schippen Schnee.")
   EXCLUDE("Donaudampfschiffahrtsgesellschaftsoberkapitan.")
   INCLUDE("diagonally parked in a parallel universe")
   INCLUDE("Share and enjoy!")
   INCLUDE("Al la apartamento parte apartenas aparta portaparanto!")
   INCLUDE("Kiu bone distingas, tiu bone lernas.")
   INCLUDE("Kredu Min, Sinjorino!")
   INCLUDE("Ghis revidersehen!")
   INCLUDE("Es ist immer gut, mehr zu wissen als die anderen!")
   EXCLUDE("Zwischen Himmel und Erde.")
   INCLUDE("Tiu ne eraras, kiu nenion faras.")
   INCLUDE("Ne malplenigu vian akvosakon je ekvido de miragho.")
   INCLUDE("Lasu flanken kion vi audas, ne kredu chion kion vi vidas.")
   INCLUDE("Kontrauu al ministro, sed neniam al lia pordisto.")
   INCLUDE("Se vi ne povas esti stelo en chielo, estu kandelo surtere.")
   INCLUDE("Ne jhetu sagojn de malbeno al via malamiko, char eble vi trafos vian amikon.")
   INCLUDE("Unu libera homo povas liberigi tutan urbon.")
   INCLUDE("Sometimes ya gotta do it purely for the hack value.")
   INCLUDE("Ek al komuna laboro!")
   INCLUDE("Fartu bone!")
   INCLUDE("Under capitalism man exploits man; under socialism the reverse is true.") /* Polish proverb */
   INCLUDE("Was wir wissen, ist ein Tropfen, was wir nicht wissen, ist ein Ozean.")
   INCLUDE("La vivo estas batalo, kiu finighas per malvenko.")
   INCLUDE("A picture may be worth a thousand words, but it takes up way more diskspace.")
   INCLUDE("Printempo semas, autuno rikoltas.")
   INCLUDE("Kia la semo, tia la rikolto.")
   INCLUDE("Elmetu mielon, mushoj alflugos.")
   INCLUDE("Ankau morgau estas tago.")
   INCLUDE("La lokomotivo estas tre scivola... konstante ghi diras chu, chu, chu, chu...")
   INCLUDE("Hey Lisa, they're having a big party down at the Allele Pool tonight!")
   INCLUDE("WD-40, duct tape and Vim; what more could you possibly need?")
   EXCLUDE("But a zero-sum game it is always.") /* Hugo Nebel */
   INCLUDE("Aliloka chielo estas sama chielo.")
   EXCLUDE("Truth is the daughter of time.")
   INCLUDE("Je iuj tagoj mi estas kolombo, je aliaj tagoj mi estas statuo.")
   INCLUDE("Sur la klavaro de Vivo, chiam restigu unu fingron sur la Eskapo-klavo.")
   INCLUDE("Se ne ekzistus finan minuton, nenio estus farita.")
   INCLUDE("Se via hundo diras al vi ke vi estas freneza, do vi ja estas.")
   INCLUDE("Okupita pri fari nenion.") /* Busy doing nothing. (Micke Englund: Fari nenion) */
   INCLUDE("Ree mi decidas ke mi morgau novan vivon komencos...") /* Amplifiki: Promesoj */
   INCLUDE("Volapukano diras, ke chiu volapukano mensogas.")
   INCLUDE("La studado estas la plej altnivela plezuro de la civilizita homo.") /* Levu la manojn, p 114 */
   INCLUDE("Esperantio - la plej granda lando de la mondo!")
   INCLUDE("Inter hundoj hundu.")
#endif

   /*
   Leave this one at the end. No comma.
   Though a trailing comma is sometimes (always?) legal.
    */

   "It was the end of a very long day." /* Groundhog Day */

   };

static int numfortunes = sizeof(fortunes)/sizeof(fortunes[0]);

FILE *cookiejar;
char cookie[MAXLENGTH];
char fortune[MAXLENGTH];

#ifdef _MICROC_
extern unsigned int RAND_SEED;
int reseed()
   {
   int year;
   int month;
   int day;
   int hour;
   int minute;
   int second;
   get_date(&day,&month,&year);
   get_time(&hour,&minute,&second);
   RAND_SEED = (10000*day)+(100*minute)+(second);
   }
#else
int reseed()
   {
#ifdef _MSC_VER
   srand((unsigned)time(NULL));
#else
   srand(time(NULL));
#endif
   }
#endif

char *internaldata()
   {
   if (!numfortunes)
      {
      return NULL;
      }
   else
      {
      --numfortunes;
      strncpy(cookie,fortunes[numfortunes],sizeof(cookie));
      cookie[MAXLENGTH-1] = 0;
      return cookie;
      }
   }

char *filedata()
   {
   return fgets(cookie,sizeof(cookie),cookiejar);
   }

int donothing()
   {
   }

int closer()
   {
   fclose(cookiejar);
   }

#ifdef _MICROC_
#define FUNCTIONPOINTER(x) *x
#define FUNCTIONADDRESS(x) &x
#else
#define FUNCTIONPOINTER(x) (*x)()
#define FUNCTIONADDRESS(x) x
#endif

int main( argc, argv )
int argc;
char **argv;
   {
   int n;
   char *FUNCTIONPOINTER(chomp);
   int FUNCTIONPOINTER(cleanup);
   chomp = FUNCTIONADDRESS(internaldata);
   cleanup = FUNCTIONADDRESS(donothing);
   reseed();
   strcpy(fortune,"xyzzy!");
   if (argc>1)
      {
      if ( NULL == ( cookiejar = fopen(argv[1],"r") ) )
         {
         puts(IDENTIFICATION1);
         puts(IDENTIFICATION2);
         puts(IDENTIFICATION3);
         printf("%d embedded fortunes!\n",sizeof(fortunes)/sizeof(char *));
         puts("Usage: fortune [fortunefilename]");
         if ( '?' != *argv[1]) printf("Unable to open %s, but I'll give you a cookie anyway...\n",argv[1]);
         }
      else
         {
         chomp = FUNCTIONADDRESS(filedata);
         cleanup = FUNCTIONADDRESS(closer);
         }
      }
   for ( n=2; NULL != chomp(); n++ ) if (!(rand()%n)) strcpy(fortune,cookie);
   cleanup();
   if ( '\n' == fortune[strlen(fortune)-1] ) fortune[strlen(fortune)-1] = 0;
   puts(fortune);
   }

